miml package
============

Subpackages
-----------

.. toctree::
   :maxdepth: 4

   miml.classifier
   miml.data
   miml.datasets
   miml.report
   miml.transformation

Module contents
---------------

.. automodule:: miml
   :members:
   :undoc-members:
   :show-inheritance:
